# -*- coding: utf-8 -*-

class AdditionalInformationEnum(object):

    """Implementation of the 'AdditionalInformation' enum.

    TODO: type enum description here.

    Attributes:
        UNIQUETRANSACTIONID: TODO: type description here.
        INSTRUCTEDCURRENCY: TODO: type description here.
        INSTRUCTEDAMOUNT: TODO: type description here.
        SETTLEDCURRENCY: TODO: type description here.
        SETTLEDAMOUNT: TODO: type description here.
        SETTLEDDATE: TODO: type description here.
        DEBITCREDITINDICATOR: TODO: type description here.
        TRANSACTIONTYPE: TODO: type description here.
        TRANSACTIONNARRATIVE: TODO: type description here.
        ADDITIONALNARRATIVE: TODO: type description here.
        ORIGINATORBANK: TODO: type description here.
        ORIGINATORACCOUNTNUMBER: TODO: type description here.
        ORIGINATORNAMEADDRESSCOMBINED: TODO: type description here.
        ORIGINATORACCOUNTNAME: TODO: type description here.
        ORIGINATORADDRESS: TODO: type description here.
        ORIGINATORCITY: TODO: type description here.
        ORIGINATORCOUNTRY: TODO: type description here.
        ORIGINATORDOB: TODO: type description here.
        ORIGINATORNATIONALID: TODO: type description here.
        BENEFICIARYNAMEADDRESSCOMBINED: TODO: type description here.
        BENEFICIARYNAME: TODO: type description here.
        BENEFICIARYDOB: TODO: type description here.
        BENEFICIARYNATIONALID: TODO: type description here.
        BENEFICIARYADDRESS: TODO: type description here.
        BENEFICIARYCITY: TODO: type description here.
        BENEFICIARYCOUNTRY: TODO: type description here.

    """

    UNIQUETRANSACTIONID = 'UniqueTransactionId'

    INSTRUCTEDCURRENCY = 'InstructedCurrency'

    INSTRUCTEDAMOUNT = 'InstructedAmount'

    SETTLEDCURRENCY = 'SettledCurrency'

    SETTLEDAMOUNT = 'SettledAmount'

    SETTLEDDATE = 'SettledDate'

    DEBITCREDITINDICATOR = 'DebitCreditIndicator'

    TRANSACTIONTYPE = 'TransactionType'

    TRANSACTIONNARRATIVE = 'TransactionNarrative'

    ADDITIONALNARRATIVE = 'AdditionalNarrative'

    ORIGINATORBANK = 'OriginatorBank'

    ORIGINATORACCOUNTNUMBER = 'OriginatorAccountNumber'

    ORIGINATORNAMEADDRESSCOMBINED = 'OriginatorNameAddressCombined'

    ORIGINATORACCOUNTNAME = 'OriginatorAccountName'

    ORIGINATORADDRESS = 'OriginatorAddress'

    ORIGINATORCITY = 'OriginatorCity'

    ORIGINATORCOUNTRY = 'OriginatorCountry'

    ORIGINATORDOB = 'OriginatorDOB'

    ORIGINATORNATIONALID = 'OriginatorNationalId'

    BENEFICIARYNAMEADDRESSCOMBINED = 'BeneficiaryNameAddressCombined'

    BENEFICIARYNAME = 'BeneficiaryName'

    BENEFICIARYDOB = 'BeneficiaryDOB'

    BENEFICIARYNATIONALID = 'BeneficiaryNationalId'

    BENEFICIARYADDRESS = 'BeneficiaryAddress'

    BENEFICIARYCITY = 'BeneficiaryCity'

    BENEFICIARYCOUNTRY = 'BeneficiaryCountry'

