# -*- coding: utf-8 -*-

class BeneficiaryIdentityFieldInputEnum(object):

    """Implementation of the 'BeneficiaryIdentityFieldInput' enum.

    Supported input types for a beneficiary identity UI.

    Attributes:
        TEXT: TODO: type description here.
        DATE: TODO: type description here.
        NUMBER: TODO: type description here.
        LIST: TODO: type description here.

    """

    TEXT = 'text'

    DATE = 'date'

    NUMBER = 'number'

    LIST = 'list'

