# -*- coding: utf-8 -*-

class ServiceLevelEnum(object):

    """Implementation of the 'ServiceLevel' enum.

    Supported service levels for a payout request (standard or express).

    Attributes:
        STANDARD: TODO: type description here.
        EXPRESS: TODO: type description here.

    """

    STANDARD = 'standard'

    EXPRESS = 'express'

