# -*- coding: utf-8 -*-

class IdentityEntityEnum(object):

    """Implementation of the 'IdentityEntity' enum.

    Supported identity entity types.

    Attributes:
        INDIVIDUAL: TODO: type description here.
        LEGALENTITY: TODO: type description here.

    """

    INDIVIDUAL = 'individual'

    LEGALENTITY = 'legalEntity'

