# -*- coding: utf-8 -*-

class MoneyMovementTypeEnum(object):

    """Implementation of the 'MoneyMovementType' enum.

    Specifies whether a money movement is a debit or credit

    Attributes:
        DEBIT: TODO: type description here.
        CREDIT: TODO: type description here.

    """

    DEBIT = 'Debit'

    CREDIT = 'Credit'

