# -*- coding: utf-8 -*-

class BeneficiaryBankAccountFieldInputEnum(object):

    """Implementation of the 'BeneficiaryBankAccountFieldInput' enum.

    Supported input types for a bank registration UI.

    Attributes:
        TEXT: TODO: type description here.
        LIST: TODO: type description here.

    """

    TEXT = 'text'

    LIST = 'list'

