# -*- coding: utf-8 -*-

class FXMethodEnum(object):

    """Implementation of the 'FXMethod' enum.

    Method of FX that will be used to settle the payout request.

    Attributes:
        ENUM_NO FX: TODO: type description here.
        ENUM_FORWARD FX: TODO: type description here.
        ENUM_FX ON RECEIPT: TODO: type description here.

    """

    ENUM_NO_FX = 'no fx'

    ENUM_FORWARD_FX = 'forward fx'

    ENUM_FX_ON_RECEIPT = 'fx on receipt'

