# -*- coding: utf-8 -*-

class IdTypeEnum(object):

    """Implementation of the 'idType' enum.

    TODO: type enum description here.

    Attributes:
        MERCHANT: TODO: type description here.
        EARTHPORT: TODO: type description here.

    """

    MERCHANT = 'merchant'

    EARTHPORT = 'earthport'

