# -*- coding: utf-8 -*-

class GrantTypeEnum(object):

    """Implementation of the 'grant_type' enum.

    TODO: type enum description here.

    Attributes:
        CLIENT_CREDENTIALS: TODO: type description here.

    """

    CLIENT_CREDENTIALS = 'client_credentials'

