# -*- coding: utf-8 -*-

class SortOrderEnum(object):

    """Implementation of the 'sortOrder' enum.

    TODO: type enum description here.

    Attributes:
        DESC: TODO: type description here.
        ASC: TODO: type description here.

    """

    DESC = 'DESC'

    ASC = 'ASC'

