# -*- coding: utf-8 -*-

class ActionEnum(object):

    """Implementation of the 'action' enum.

    TODO: type enum description here.

    Attributes:
        VALIDATE: TODO: type description here.

    """

    VALIDATE = 'validate'

