# -*- coding: utf-8 -*-

class BeneficiaryBankAccountStatusEnum(object):

    """Implementation of the 'BeneficiaryBankAccountStatus' enum.

    Type which defines a beneficiary bank account status. (ie. active or
    deleted).

    Attributes:
        ACTIVE: TODO: type description here.
        INACTIVE: TODO: type description here.

    """

    ACTIVE = 'ACTIVE'

    INACTIVE = 'INACTIVE'

