# -*- coding: utf-8 -*-


class FXTicketID(object):

    """Implementation of the 'FXTicketID' model.

    The unique FX Ticket ID generated by the Earthport payment system.

    Attributes:
        ticket_id (int): Generic entity identity.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ticket_id":'ticketID'
    }

    def __init__(self,
                 ticket_id=None):
        """Constructor for the FXTicketID class"""

        # Initialize members of the class
        self.ticket_id = ticket_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ticket_id = dictionary.get('ticketID')

        # Return an object of this model
        return cls(ticket_id)


