# -*- coding: utf-8 -*-

class BeneficiaryIdentityEntityTypeEnum(object):

    """Implementation of the 'beneficiaryIdentityEntityType' enum.

    TODO: type enum description here.

    Attributes:
        LEGALENTITY: Legal Entity such as a company.
        INDIVIDUAL: Individual person.

    """

    LEGALENTITY = 'legalEntity'

    INDIVIDUAL = 'individual'

